<?php
/**
 * The prerelease view file of thinkwizard module of ZenTaoPMS.
 * @copyright   Copyright 2009-2024 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.zentao.net)
 * @license     ZPL(https://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Zemei Wang <wangzemei@easycorp.ltd>
 * @package     thinkwizard
 * @link        https://www.zentao.net
 */
namespace zin;

/* featurebar */
$currentNav = 'prerelease';
include './navs.html.php';

$isBcg      = $wizard->model == 'bcg';
$isChinese  = strpos($app->getClientLang(), 'zh-') !== false;
$prerelease = null;
if(isset($wizard->config['prerelease'])) $prerelease = $wizard->config['prerelease'];

$defaultSplitValue = array(null, null);
if($isBcg) $defaultSplitValue = array('0.1', '2');

$showSplitCount = array();
if($splitCount[0] != '' && $splitCount[1] != '')
{
    $showSplitCount = $splitCount;
}
else
{
    $showSplitCount[0] = $splitCount[0] != '' ? $splitCount[0] : (isset($prerelease['splitCount']) ? $prerelease['splitCount'][0] : 1);
    $showSplitCount[1] = $splitCount[1] != '' ? $splitCount[1] : (isset($prerelease['splitCount']) ? $prerelease['splitCount'][1] : 1);
}

$previewKey       = $this->thinkwizardZen->findBlockKey($config->thinkwizard->previewBlocks['MQA'], $showSplitCount);
$fnBuildSplitName = function(string $axis) use ($lang, $prerelease, $isChinese, $showSplitCount, $isBcg, $defaultSplitValue)
{
    $splitCounts = $showSplitCount[$axis];
    if($splitCounts == 0) return array();

    $className  = $isChinese ? 'justify-center' : 'text-clip';
    $splitNames = array();
    for($i = 0; $i < $splitCounts; $i++)
    {
        $splitNames[] = formRow
        (
            setClass('flex justify-between mt-2', "split-row-$axis"),
            $isBcg ? null : div
            (
                setClass('flex gap-2 split-name', "split-name-$axis"),
                setStyle(array('width' => 'calc(50% - 8px)')),
                div
                (
                    setClass('split-label flex items-center py-2 px-2.5 bg-gray-100 text-gray-700', $className),
                    setStyle(array('height' => '2rem')),
                    $isChinese ? null : set::title(sprintf($lang->thinkwizard->prerelease->splitName, $i + 1)),
                    span(sprintf($lang->thinkwizard->prerelease->splitName, $i + 1))
                ),
                formGroup
                (
                    set::name("prerelease[splitName][$axis][$i]"),
                    set::placeholder($lang->thinkwizard->placeholder->specificName),
                    set::value(isset($prerelease['splitName'][$axis][$i]) ? $prerelease['splitName'][$axis][$i] : '')
                )
            ),
            div
            (
                setClass('flex gap-2 split-value', "split-value-$axis", isset($prerelease['splitType'][$axis]) && $prerelease['splitType'][$axis] == 0 ? 'hidden' : null),
                setStyle(array('width' => 'calc(50% - 8px)')),
                div
                (
                    setClass('split-label flex items-center py-2 px-2.5 bg-gray-100 text-gray-700', $className),
                    setStyle(array('height' => '2rem')),
                    $isChinese ? null : set::title(sprintf($lang->thinkwizard->prerelease->splitValue, $i + 1)),
                    span(sprintf($lang->thinkwizard->prerelease->splitValue, $i + 1))
                ),
                formGroup
                (
                    inputControl
                    (
                        set::prefix($axis == '0' ? 'y=' : 'x='),
                        set::prefixWidth('30'),
                        input
                        (
                            set::name("prerelease[splitValue][$axis][$i]"),
                            set::required(true),
                            set::type('number'),
                            set::placeholder($lang->thinkwizard->placeholder->specificValue),
                            set::value(isset($prerelease['splitValue'][$axis][$i]) ? $prerelease['splitValue'][$axis][$i] : $defaultSplitValue[$axis]),
                            on::input('changeSplitValue')
                        )
                    )
                )
            )
        );
    }

    return $splitNames;
};

$fnBuldSplitSetting = function() use ($lang, $showSplitCount, $fnBuildSplitName, $prerelease, $isBcg)
{
    $axisList  = array('0', '1');
    $splitForm = array();
    foreach($axisList as $axis)
    {
        $splitForm[] = array
        (
            div
            (
                setClass('bg-gray-100 bg-opacity-50 rounded-sm pt-2 pb-3 px-4 col gap-3', "split-item-$axis"),
                formRow
                (
                    setClass('flex gap-4'),
                    $isBcg ? array(
                        formHidden("prerelease[splitCount][$axis]", 1),
                        formHidden("prerelease[isDefineName][$axis]", '0')
                    ) : null,
                    formGroup
                    (
                        set::width('calc(50% - 8px)'),
                        set::label($lang->thinkwizard->prerelease->splitCount[$axis]),
                        picker
                        (
                            set::name("prerelease[splitCount][$axis]"),
                            set::inline(true),
                            set::required(true),
                            set::disabled($isBcg),
                            set::value($showSplitCount[$axis]),
                            set::items($lang->thinkwizard->prerelease->splitCountOptions),
                            on::change()->call('changeSplitCount', jsRaw('event.target.value'), $axis)
                        )
                    ),
                    formGroup
                    (
                        setClass($showSplitCount[$axis] == '0' ? 'hidden' : ''),
                        set::width('calc(50% - 8px)'),
                        set::label($lang->thinkwizard->prerelease->splitType),
                        set::labelHint($lang->thinkwizard->hint->splitType),
                        picker
                        (
                            set::name("prerelease[splitType][$axis]"),
                            set::inline(true),
                            set::required(true),
                            set::value(isset($prerelease['splitType'][$axis]) ? $prerelease['splitType'][$axis] : 1),
                            set::items($lang->thinkwizard->prerelease->splitTypeOptions),
                            on::change()->call('changeSplitType', jsRaw('event.target.value'), $axis),
                            on::inited()->do(
                                "$('.think-prerelease .split-value-$axis').toggleClass('hidden', $(`[name='prerelease[splitType][$axis]']`).zui('picker').$.value == 0);",
                                "$('.think-prerelease .split-row-$axis').toggleClass('mt-2', !($(`input[name='prerelease[isDefineName][$axis]']:checked`).val() == 0 && $(`[name='prerelease[splitType][$axis]']`).val() == 0));",
                                "const isBcg = $('.think-prerelease').data('isBcg');",
                                "if(isBcg) $('.think-prerelease .split-item-$axis').toggleClass('gap-3', $(`[name='prerelease[splitType][$axis]']`).val() != 0);"
                            )
                        )
                    )
                ),
                div
                (
                    $isBcg ? null : formGroup
                    (
                        setClass($showSplitCount[$axis] == '0' ? 'hidden' : ''),
                        set::label($lang->thinkwizard->prerelease->isDefineName),
                        radioList
                        (
                            set::name("prerelease[isDefineName][$axis]"),
                            set::items($lang->thinkwizard->objects->specifyObjectOptions),
                            set::value(isset($prerelease['isDefineName'][$axis]) ? $prerelease['isDefineName'][$axis] : '0'),
                            set::inline(true),
                            on::change()->do(
                                "$('.split-name-$axis').toggleClass('hidden', event.target.value == 0);",
                                "$('.think-prerelease .split-row-$axis').toggleClass('mt-2', !($(`input[name='prerelease[isDefineName][$axis]']:checked`).val() == 0 && $(`[name='prerelease[splitType][$axis]']`).val() == 0));"
                            )
                        )
                    ),
                    $fnBuildSplitName($axis)
                )
            )
        );
    }
    return div
    (
        div($lang->thinkwizard->prerelease->splitSetting),
        div(setCLass('mt-2 col gap-3'), $splitForm)
    );
};

$fnBuldBlocks = function() use ($lang, $config, $showSplitCount, $wizard)
{
    $splitKey = array_search($showSplitCount, $config->thinkwizard->previewBlocks['MQA']);
    if($splitKey == 0) return array();

    $blockCount = $config->thinkwizard->areaCount['MQA'][$splitKey];
    $className  = $showSplitCount[1] == 0 ? 'col gap-2' : 'flex flex-wrap gap-2';
    $blockFlex  = '0 0 calc(50% - 6px)';
    if($showSplitCount[1] == 2) $blockFlex = '0 0 calc(33.33% - 6px)';

    $blocks = array();
    for($i = 0; $i < $blockCount; $i++)
    {
        $blocks[] = formGroup
        (
            setClass('prerelease-block bg-gray-100 bg-opacity-50 rounded-sm'),
            setStyle(array('flex' => "$blockFlex")),
            set::label($lang->thinkwizard->prerelease->area . $lang->thinkwizard->blockList[$i]),
            set::name("blocks[$i]"),
            set::placeholder($lang->thinkwizard->placeholder->areaName),
            set::value(isset($wizard->blocks[$i]) ? $wizard->blocks[$i] : ''),
        );
    }

    return formGroup
    (
        set::required(true),
        set::label($lang->thinkwizard->prerelease->areaDefination),
        set::labelHint($lang->thinkwizard->hint->areaDefination),
        div(setClass('mt-1', $className), $blocks)
    );
};

formPanel
(
    setClass('h-full pt-1 col think-prerelease items-stretch px-0 py-0'),
    setData(array('marketID' => $marketID, 'wizardID' => $wizard->id, 'splitCount' => $splitCount, 'isBcg' => $isBcg)),
    on::inited()->call('initedPrerelease'),
    set::bodyClass('p-0'),
    set::layout('grid'),
    set::actionsClass('shadow-xl py-3'),
    set::actions(array(
        array('text' => $lang->thinkwizard->abbr->publish, 'class' => 'btn primary', 'btnType' => 'button', 'onclick' => 'publishForPrerelease()')
    )),
    div
    (
        setClass('w-full flex items-stretch gap-3'),
        setStyle(array('min-height' => 'calc(100vh - 168px)')),
        panel
        (
            setClass('w-1/2 flex-1'),
            set::headingClass('h-12 border-b border-gray-100'),
            set::titleClass('font-medium text-gray-950 text-md'),
            set::title($lang->thinkwizard->resultArea->config),
            set::bodyClass('col gap-3'),
            $fnBuldSplitSetting,
            $fnBuldBlocks,
            formGroup
            (
                set::label($lang->thinkwizard->introduction),
                set::name('introduction'),
                set::value($wizard->introduction),
                set::placeholder($lang->thinkwizard->placeholder->introduction)
            ),
            formGroup
            (
                set::label($lang->thinkwizard->suggestion),
                editor
                (
                    set::placeholder($lang->thinkwizard->placeholder->suggestion),
                    set::name('suggestion'),
                    html(htmlspecialchars_decode($wizard->suggestion))
                )
            )
        ),
        panel
        (
            setClass('w-1/2 flex-1'),
            set::headingClass('h-12 border-b border-gray-100'),
            set::titleClass('font-medium text-gray-950 text-md'),
            set::title($lang->thinkwizard->resultArea->preview),
            thinkResult(set::mode('preview'), set::wizard($wizard), set::previewKey($previewKey), set::blocks(array()))
        )
    )
);
